@@ -33,10 +33,10 @@ from traits.api \
 from pyface.wx.drag_and_drop \
     import PythonDropTarget, PythonDropSource
 
-from .dock_sizer \
+from dock_sizer \
     import DockControl, FEATURE_EXTERNAL_DRAG
 
-from .ifeature_tool \
+from ifeature_tool \
     import IFeatureTool
 
 #-------------------------------------------------------------------------------
@@ -350,7 +350,7 @@ class FeatureBar ( HasPrivateTraits ):
             else:
                 # Handle a normal object being dropped:
                 wx, wy = self.control.GetScreenPosition()
-                feature.set( x = wx + x, y = wy + y )
+                feature.trait_set( x = wx + x, y = wy + y )
                 feature.drop( data )
 
             return drag_result
