@@ -1,4 +1,4 @@
-
+from __future__ import absolute_import
 
 from traits.testing.unittest_tools import unittest
 
@@ -13,7 +13,6 @@ no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
 
 @unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
 class TestHeadingText(unittest.TestCase, GuiTestAssistant):
-
     def setUp(self):
         GuiTestAssistant.setUp(self)
         self.window = Window()
@@ -34,32 +33,34 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
 
     def test_lifecycle(self):
         # test that destroy works
-        self.widget = HeadingText(self.window.control)
-        self.event_loop()
-        self.widget.destroy()
-        self.event_loop()
+        with self.event_loop():
+            self.widget = HeadingText(self.window.control)
+        with self.event_loop():
+            self.widget.destroy()
 
     def test_message(self):
         # test that create works with message
-        self.widget = HeadingText(self.window.control, text="Hello")
-        self.event_loop()
-        self.widget.destroy()
-        self.event_loop()
+        with self.event_loop():
+            self.widget = HeadingText(self.window.control, text="Hello")
+        with self.event_loop():
+            self.widget.destroy()
 
     def test_image(self):
         # test that image works
         # XXX this image doesn't make sense here, but that's fine
         # XXX this isn't implemented in qt4 backend, but shouldn't fail
-        self.widget = HeadingText(self.window.control, image=ImageResource('core.png'))
-        self.event_loop()
-        self.widget.destroy()
-        self.event_loop()
+        with self.event_loop():
+            self.widget = HeadingText(
+                self.window.control, image=ImageResource('core.png')
+            )
+        with self.event_loop():
+            self.widget.destroy()
 
     def test_level(self):
         # test that create works with level
         # XXX this image doesn't make sense here, but that's fine
         # XXX this isn't implemented in qt4 backend, but shouldn't fail
-        self.widget = HeadingText(self.window.control, level=2)
-        self.event_loop()
-        self.widget.destroy()
-        self.event_loop()
+        with self.event_loop():
+            self.widget = HeadingText(self.window.control, level=2)
+        with self.event_loop():
+            self.widget.destroy()
