@@ -1,4 +1,4 @@
-
+from __future__ import absolute_import
 
 from traits.testing.unittest_tools import unittest
 
@@ -8,13 +8,14 @@ from ..toolkit import toolkit_object
 GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
 no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
 
-ModalDialogTester = toolkit_object('util.modal_dialog_tester:ModalDialogTester')
+ModalDialogTester = toolkit_object(
+    'util.modal_dialog_tester:ModalDialogTester'
+)
 no_modal_dialog_tester = (ModalDialogTester.__name__ == 'Unimplemented')
 
 
 @unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
 class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
-
     def setUp(self):
         GuiTestAssistant.setUp(self)
         self.dialog = ProgressDialog()
@@ -28,48 +29,49 @@ class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
 
     def test_create(self):
         # test that creation and destruction works as expected
-        self.dialog._create()
-        self.event_loop()
-        self.dialog.destroy()
-        self.event_loop()
+        with self.event_loop():
+            self.dialog._create()
+        with self.event_loop():
+            self.dialog.destroy()
 
     def test_destroy(self):
         # test that destroy works even when no control
-        self.dialog.destroy()
-        self.event_loop()
+        with self.event_loop():
+            self.dialog.destroy()
 
     def test_can_cancel(self):
         # test that creation works with can_cancel
-        self.dialog.can_cancel =  True
-        self.dialog._create()
-        self.event_loop()
-        self.dialog.destroy()
-        self.event_loop()
+        self.dialog.can_cancel = True
+        with self.event_loop():
+            self.dialog._create()
+        with self.event_loop():
+            self.dialog.destroy()
 
     def test_show_time(self):
         # test that creation works with show_time
-        self.dialog.show_time =  True
-        self.dialog._create()
-        self.event_loop()
-        self.dialog.destroy()
-        self.event_loop()
+        self.dialog.show_time = True
+        with self.event_loop():
+            self.dialog._create()
+        with self.event_loop():
+            self.dialog.destroy()
 
     @unittest.skip("not implemented in any backend")
     def test_show_percent(self):
         # test that creation works with show_percent
-        self.dialog.show_percent =  True
-        self.dialog._create()
-        self.event_loop()
-        self.dialog.destroy()
-        self.event_loop()
+        self.dialog.show_percent = True
+        with self.event_loop():
+            self.dialog._create()
+        with self.event_loop():
+            self.dialog.destroy()
 
     def test_update(self):
         self.dialog.min = 0
         self.dialog.max = 10
         self.dialog.open()
         for i in range(11):
-            result = self.dialog.update(i)
-            self.event_loop()
+            with self.event_loop():
+                result = self.dialog.update(i)
+
             self.assertEqual(result, (True, False))
 
         self.assertIsNone(self.dialog.control)
@@ -78,7 +80,8 @@ class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
     def test_update_no_control(self):
         self.dialog.min = 0
         self.dialog.max = 10
-        result = self.dialog.update(1)
+        with self.event_loop():
+            result = self.dialog.update(1)
         self.assertEqual(result, (None, None))
 
     def test_incomplete_update(self):
@@ -87,12 +90,12 @@ class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
         self.can_cancel = True
         self.dialog.open()
         for i in range(5):
-            result = self.dialog.update(i)
-            self.event_loop()
+            with self.event_loop():
+                result = self.dialog.update(i)
             self.assertEqual(result, (True, False))
         self.assertIsNotNone(self.dialog.control)
-        self.dialog.close()
-        self.event_loop()
+        with self.event_loop():
+            self.dialog.close()
 
         self.assertIsNone(self.dialog.control)
 
@@ -101,9 +104,10 @@ class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.max = 10
         self.dialog.open()
         for i in range(11):
-            self.dialog.change_message('Updating {}'.format(i))
-            result = self.dialog.update(i)
-            self.event_loop()
+            with self.event_loop():
+                self.dialog.change_message('Updating {}'.format(i))
+                result = self.dialog.update(i)
+
             self.assertEqual(result, (True, False))
             self.assertEqual(self.dialog.message, 'Updating {}'.format(i))
         self.assertIsNone(self.dialog.control)
@@ -114,8 +118,9 @@ class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.show_time = True
         self.dialog.open()
         for i in range(11):
-            result = self.dialog.update(i)
-            self.event_loop()
+            with self.event_loop():
+                result = self.dialog.update(i)
+
             self.assertEqual(result, (True, False))
         self.assertIsNone(self.dialog.control)
 
@@ -124,18 +129,20 @@ class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.max = 0
         self.dialog.open()
         for i in range(10):
-            result = self.dialog.update(i)
-            self.event_loop()
+            with self.event_loop():
+                result = self.dialog.update(i)
+
             self.assertEqual(result, (True, False))
-        self.dialog.close()
-        self.event_loop()
+
+        with self.event_loop():
+            self.dialog.close()
         # XXX not really sure what correct behaviour is here
 
     def test_update_negative(self):
         self.dialog.min = 0
         self.dialog.max = -10
         with self.assertRaises(AttributeError):
-            self.dialog.open()
-            self.event_loop()
+            with self.event_loop():
+                self.dialog.open()
 
         self.assertIsNone(self.dialog.control)
